@@ -1,8 +1,4 @@
 #!/usr/bin/python3
-# coding: utf-8
-#
-# Univention Management Console module:
-#  System Diagnosis UMC module
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -34,22 +30,20 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-
-import ldap
 import socket
 import subprocess
 
-import univention
-import univention.uldap
-import univention.lib.misc
-import univention.admin.uldap
-import univention.admin.modules as udm_modules
-import univention.config_registry
-from univention.config_registry import handler_set as ucr_set
-from univention.config_registry import handler_unset as ucr_unset
-from univention.management.console.modules.diagnostic import Critical, ProblemFixed, MODULE
+import ldap
 
+import univention.admin.modules as udm_modules
+import univention.admin.uldap
+import univention.config_registry
+import univention.lib.misc
+import univention.uldap
+from univention.config_registry import handler_set as ucr_set, handler_unset as ucr_unset, ucr_live as configRegistry
 from univention.lib.i18n import Translation
+from univention.management.console.modules.diagnostic import MODULE, Critical, Instance, ProblemFixed
+
 _ = Translation('univention-management-console-module-diagnostic').translate
 run_descr = ["Trying to authenticate with machine password against LDAP  Similar to running: univention-ldapsearch -LLLs base dn"]
 title = _('Check machine password')
@@ -61,30 +55,27 @@ links = [{
 }]
 
 
-def fix_machine_password(umc_instance):
-	configRegistry = univention.config_registry.ConfigRegistry()
-	configRegistry.load()
-
+def fix_machine_password(umc_instance: Instance) -> None:
 	role = configRegistry.get('server/role')
 	valid_roles = ('domaincontroller_master', 'domaincontroller_backup', 'domaincontroller_slave', 'memberserver')
 	if role in valid_roles:
 		restore_machine_password(role, umc_instance.get_user_ldap_connection())
 
 		if configRegistry.is_true('server/password/change', True):
-			change_server_password(configRegistry)
+			change_server_password()
 		return run(umc_instance, retest=True)
 
 	error_description = _('Unable to fix machine password on {}'.format(role))
 	raise Critical(description=error_description)
 
 
-def reset_password_change(umc_instance):
+def reset_password_change(umc_instance: Instance) -> None:
 	MODULE.process('Resetting server/password/change')
 	ucr_unset(['server/password/change'])
 	return run(umc_instance, retest=True)
 
 
-def reset_password_interval(umc_instance):
+def reset_password_interval(umc_instance: Instance) -> None:
 	MODULE.process('Resetting server/password/interval=21')
 	ucr_set(['server/password/interval=21'])
 	return run(umc_instance, retest=True)
@@ -97,7 +88,7 @@ actions = {
 }
 
 
-def check_machine_password(master=True):
+def check_machine_password(master: bool = True) -> bool:
 	try:
 		univention.uldap.getMachineConnection(ldap_master=master)
 	except ldap.INVALID_CREDENTIALS:
@@ -105,8 +96,8 @@ def check_machine_password(master=True):
 	return True
 
 
-def change_server_password(configRegistry):
-	interval = configRegistry.get('server/password/interval', '21')
+def change_server_password() -> None:
+	interval = configRegistry.get_int('server/password/interval', 21)
 	ucr_set('server/password/interval=-1')
 	try:
 		cmd = ['/usr/lib/univention-server/server_password_change']
@@ -125,7 +116,7 @@ def change_server_password(configRegistry):
 		ucr_set('server/password/interval={}'.format(interval))
 
 
-def restore_machine_password(role, ldap_connection):
+def restore_machine_password(role: str, ldap_connection: univention.admin.uldap.access) -> None:
 	with open('/etc/machine.secret') as fob:
 		password = fob.read().rstrip('\n')
 
@@ -145,11 +136,8 @@ def restore_machine_password(role, ldap_connection):
 		computer.modify()
 
 
-def run(_umc_instance, retest=False):
-	configRegistry = univention.config_registry.ConfigRegistry()
-	configRegistry.load()
-
-	error_descriptions = list()
+def run(_umc_instance: Instance, retest: bool = False) -> None:
+	error_descriptions = []
 	buttons = [{
 		'action': 'fix_machine_password',
 		'label': _('Fix machine password'),
@@ -165,10 +153,7 @@ def run(_umc_instance, retest=False):
 		error_descriptions.append(error)
 
 	password_change = configRegistry.is_true('server/password/change', True)
-	try:
-		change_interval = int(configRegistry.get('server/password/interval', '21'))
-	except TypeError:
-		change_interval = 21
+	change_interval = configRegistry.get_int('server/password/interval', 21)
 
 	error_change = _('Note that password rotation is disabled via the UCR variable server/password/change.')
 	error_interval = _('Note that server/password/interval is set to {}.')
