@@ -1,8 +1,4 @@
 #!/usr/bin/python3
-# coding: utf-8
-#
-# Univention Management Console module:
-#  System Diagnosis UMC module
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -35,11 +31,14 @@
 # <https://www.gnu.org/licenses/>.
 
 import socket
-import six.moves.urllib_parse as urlparse
-import univention.config_registry
-from univention.management.console.modules.diagnostic import Warning, MODULE
+from typing import Iterator
 
+from urllib.parse import urlsplit
+
+from univention.config_registry import ucr_live as configRegistry
 from univention.lib.i18n import Translation
+from univention.management.console.modules.diagnostic import MODULE, Instance, Warning
+
 _ = Translation('univention-management-console-module-diagnostic').translate
 
 title = _('Check resolving repository servers')
@@ -52,17 +51,14 @@ links = [{
 run_descr = ['Checks resolving repository servers']
 
 
-def repositories():
-	configRegistry = univention.config_registry.ConfigRegistry()
-	configRegistry.load()
-
+def repositories() -> Iterator[str]:
 	if configRegistry.is_true('repository/online', True):
 		yield configRegistry.get('repository/online/server', 'updates.software-univention.de/')
 		yield configRegistry.get('repository/app_center/server', 'appcenter.software-univention.de')
 
 
-def test_resolve(url):
-	parsed = urlparse.urlsplit(url if '//' in url else '//' + url)
+def test_resolve(url: str) -> bool:
+	parsed = urlsplit(url if '//' in url else '//' + url)
 	MODULE.process("Trying to resolve address of repository server %s" % (parsed.hostname))
 	MODULE.process("Similar to running: host %s" % (parsed.hostname))
 
@@ -73,13 +69,13 @@ def test_resolve(url):
 	return True
 
 
-def unresolvable_repositories():
+def unresolvable_repositories() -> Iterator[str]:
 	for repository in repositories():
 		if not test_resolve(repository):
 			yield repository
 
 
-def run(_umc_instance):
+def run(_umc_instance: Instance) -> None:
 	error_descriptions = [_('The following FQDNs were not resolvable:')]
 	unresolvable = list(unresolvable_repositories())
 	if unresolvable:
