@@ -1,8 +1,4 @@
 #!/usr/bin/python3
-# coding: utf-8
-#
-# Univention Management Console module:
-#  System Diagnosis UMC module
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -34,15 +30,15 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-import subprocess
 import contextlib
+import subprocess
+from typing import Iterator, Optional
 
 import univention.lib.admember
-import univention.config_registry
-from univention.management.console.modules.diagnostic import Critical, MODULE
-from univention.management.console.modules.diagnostic import util
-
+from univention.config_registry import ucr_live as config_registry
 from univention.lib.i18n import Translation
+from univention.management.console.modules.diagnostic import MODULE, Critical, Instance, util
+
 _ = Translation('univention-management-console-module-diagnostic').translate
 
 title = _('Check kerberos authenticated DNS updates')
@@ -55,13 +51,13 @@ class UpdateError(Exception):
 
 
 class KinitError(UpdateError):
-	def __init__(self, principal, keytab, password_file):
+	def __init__(self, principal: str, keytab: Optional[str], password_file: Optional[str]) -> None:
 		super(KinitError, self).__init__(principal, keytab, password_file)
 		self.principal = principal
 		self.keytab = keytab
 		self.password_file = password_file
 
-	def __str__(self):
+	def __str__(self) -> str:
 		if self.keytab:
 			msg = _('`kinit` for principal {princ} with keytab {tab} failed.')
 		else:
@@ -70,18 +66,18 @@ class KinitError(UpdateError):
 
 
 class NSUpdateError(UpdateError):
-	def __init__(self, details, domainname):
+	def __init__(self, details: str, domainname: str) -> None:
 		super(NSUpdateError, self).__init__(details, domainname)
 		self.details = details
 		self.domainname = domainname
 
-	def __str__(self):
+	def __str__(self) -> str:
 		msg = _('`nsupdate` check for domain {domain} failed ({details}).')
 		return msg.format(domain=self.domainname, details=self.details)
 
 
 @contextlib.contextmanager
-def kinit(principal, keytab=None, password_file=None):
+def kinit(principal: str, keytab: Optional[str] = None, password_file: Optional[str] = None) -> Iterator[None]:
 	auth = '--keytab={tab}' if keytab else '--password-file={file}'
 	cmd = ('kinit', auth.format(tab=keytab, file=password_file), principal)
 	MODULE.process('Running: %s' % (' '.join(cmd)))
@@ -94,44 +90,42 @@ def kinit(principal, keytab=None, password_file=None):
 		subprocess.call(('kdestroy',))
 
 
-def nsupdate(server, domainname):
+def nsupdate(server: str, domainname: str) -> None:
 	process = subprocess.Popen(('nsupdate', '-g', '-t', '15'), stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
 	cmd_template = 'server {server}\nprereq yxdomain {domain}\nsend\nquit\n'
 	cmd = cmd_template.format(server=server, domain=domainname)
 	MODULE.process("Running: 'echo %s | nsupdate -g -t 15'" % (cmd,))
 
-	process.communicate(cmd)
+	process.communicate(cmd.encode("utf-8"))
 	if process.poll() != 0:
 		MODULE.error('NS Update Error at %s %s' % (server, domainname))
 		raise NSUpdateError(server, domainname)
 
 
-def get_dns_server(config_registry, active_services):
+def get_dns_server(active_services: str) -> Optional[str]:
 	if config_registry.is_true('ad/member'):
 		ad_domain_info = univention.lib.admember.lookup_adds_dc()
 		server = ad_domain_info.get('DC IP')
 	else:
-		hostname = config_registry.get('hostname')
-		domainname = config_registry.get('domainname')
 		if set(active_services) >= {'Samba 4', 'DNS'}:
-			server = ".".join([hostname, domainname])
+			server = "%(hostname)s.%(domainname)s" % config_registry
 		else:
 			# TODO: Memberserver in Samba 4 domain
 			server = None
 	return server
 
 
-def check_dns_machine_principal(server, hostname, domainname):
+def check_dns_machine_principal(server: str, hostname: str, domainname: str) -> None:
 	with kinit('{}$'.format(hostname), password_file='/etc/machine.secret'):
 		nsupdate(server, domainname)
 
 
-def check_dns_server_principal(hostname, domainname):
+def check_dns_server_principal(hostname: str, domainname: str) -> None:
 	with kinit('dns-{}'.format(hostname), keytab='/var/lib/samba/private/dns.keytab'):
 		nsupdate(hostname, domainname)
 
 
-def check_nsupdate(config_registry, server):
+def check_nsupdate(server: str):
 	hostname = config_registry.get('hostname')
 	domainname = config_registry.get('domainname')
 
@@ -147,22 +141,19 @@ def check_nsupdate(config_registry, server):
 			yield error
 
 
-def run(_umc_instance):
-	config_registry = univention.config_registry.ConfigRegistry()
-	config_registry.load()
-
+def run(_umc_instance: Instance) -> None:
 	active_services = util.active_services()
 	if not set(active_services) & {'Samba 4', 'Samba 3'}:
 		return  # ddns updates are not possible
 
 	try:
-		server = get_dns_server(config_registry, active_services)
+		server = get_dns_server(active_services)
 		if not server:
 			return
 	except NSUpdateError:
 		return  # ddns updates are not possible
 
-	problems = list(check_nsupdate(config_registry, server))
+	problems = list(check_nsupdate(server))
 	if problems:
 		ed = [_('Errors occurred while running `kinit` or `nsupdate`.')]
 		ed.extend(str(error) for error in problems)
