@@ -1,8 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
-#
-# Univention Management Console module:
-#  System Diagnosis UMC module
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -34,13 +30,16 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-import ldap
 import socket
 import subprocess
+from typing import List, Optional, Tuple
+
+import ldap
+
 import univention.uldap
 
 
-def is_service_active(service, hostname=socket.gethostname()):
+def is_service_active(service: str, hostname: str = socket.gethostname()) -> bool:
 	lo = univention.uldap.getMachineConnection()
 	raw_filter = '(&(univentionService=%s)(cn=%s))'
 	filter_expr = ldap.filter.filter_format(raw_filter, (service, hostname))
@@ -50,7 +49,7 @@ def is_service_active(service, hostname=socket.gethostname()):
 	return False
 
 
-def active_services(lo=None):
+def active_services(lo: Optional[univention.uldap.access] = None) -> Optional[List[bytes]]:
 	if not lo:
 		lo = univention.uldap.getMachineConnection()
 	res = lo.search(base=lo.binddn, scope='base', attr=['univentionService'])
@@ -60,8 +59,8 @@ def active_services(lo=None):
 	return None
 
 
-def run_with_output(cmd):
-	output = list()
+def run_with_output(cmd) -> Tuple[bool, str]:
+	output = []
 	process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
 	(stdout, stderr) = process.communicate()
 	if stdout:
